<?php

/**
 * setup.php
 *
 * Copyright (c) 1999-2002 The SquirrelMail Project Team
 * Licensed under the GNU GPL. For full terms see the file COPYING.
 *
 *  Vacation plugin. 
 *
 * $Id: setup.php,v 1.2 2003/02/16 04:20:45 dminor Exp $
 */

define('SM_PATH','../../');

function squirrelmail_plugin_init_vacation() {

    global $squirrelmail_plugin_hooks;
    $squirrelmail_plugin_hooks["optpage_register_block"]["vacation"] =
                              "squirrelmail_vacation_optpage_register_block";
}


function squirrelmail_vacation_optpage_register_block(){
    global $optpage_blocks;
    
    include_once(SM_PATH . "plugins/vacation/config.php");
    
    $optpage_blocks[] = array(
        "name" => $vac_title,
        "url"  => SM_PATH . "plugins/vacation/vac_init.php",
        "desc" => $vac_setup_message,
        "js"   => false
    );
}

?>
